// SPDX-License-Identifier: MIT
pragma solidity ^0.8.0;

import "@openzeppelin/contracts/token/ERC721/extensions/ERC721URIStorage.sol";
import "@openzeppelin/contracts/utils/Counters.sol";

/// @dev Example of a smart contract for your NFT.
contract DrupalNFT is ERC721URIStorage {
    using Counters for Counters.Counter;
    Counters.Counter private _tokenIds;

    constructor() ERC721("DrupalNFT", "DFT") {}


    /**
     * @dev NFT mint method.
     * @param website  Address of the owner.
     * @param tokenURI A URI returning NFT's metadata.
     *
     * @notice https://docs.openzeppelin.com/contracts/4.x/erc721
     */
    function createItem(address website, string memory tokenURI)
        public
        returns (uint256)
    {
        _tokenIds.increment();

        uint256 newItemId = _tokenIds.current();
        _mint(website, newItemId);
        _setTokenURI(newItemId, tokenURI);

        return newItemId;
    }
}
